local ensure_packer = function()
  local fn = vim.fn
  local install_path = fn.stdpath('data')..'/site/pack/packer/start/packer.nvim'
  if fn.empty(fn.glob(install_path)) > 0 then
    fn.system({'git', 'clone', '--depth', '1', 'https://github.com/wbthomason/packer.nvim', install_path})
    vim.cmd [[packadd packer.nvim]]
    return true
  end
  return false
end

local packer_bootstrap = ensure_packer()

return require('packer').startup(function(use)
  -- Package Manager
  use 'wbthomason/packer.nvim'

  -- Theme
  use 'Shatur/neovim-ayu'

  -- File Browser
  use { 'kyazdani42/nvim-tree.lua',
    requires = { 'kyazdani42/nvim-web-devicons', },
  }

  -- Embedded Terminal
  use {"akinsho/toggleterm.nvim", tag = '*', config = function()
    require("toggleterm").setup()
  end}

  -- Status Line
  use { 'nvim-lualine/lualine.nvim',
    requires = { 'kyazdani42/nvim-web-devicons', opt = true }
  }

  -- Color Highlighter
  use { 'norcalli/nvim-colorizer.lua' }

  -- Create pairs for brackets/quotes
  use "windwp/nvim-autopairs"

  -- Auto Commenter
  use "terrortylor/nvim-comment"

  -- LSP Client
  use 'neovim/nvim-lspconfig'

  -- Autocompletion
  use 'hrsh7th/nvim-cmp'            -- Autocompletion plugin
  use 'hrsh7th/cmp-nvim-lsp'        -- LSP source for nvim-cmp
  use 'saadparwaiz1/cmp_luasnip'    -- Snippets source for nvim-cmp
  use 'L3MON4D3/LuaSnip'            -- Snippets plugin

  if packer_bootstrap then
    require('packer').sync()
  end
end)
